unit Unit1;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, Buttons, WPPanel, ExtCtrls, WPTbar, WpWinCtr, WPRich,
  StdCtrls, WPDefs;

type
  TForm1 = class(TForm)
    WPToolPanel1: TWPToolPanel;
    WPRichText1 : TWPRichText;
    WPToolButton3: TWPToolButton;
    WPToolButton4: TWPToolButton;
    WPToolButton5: TWPToolButton;
    WPToolButton6: TWPToolButton;
    WPToolButton7: TWPToolButton;
    WPToolButton8: TWPToolButton;
    WPToolButton9: TWPToolButton;
    OpenDialog1: TOpenDialog;
    WPToolPanel2: TWPToolPanel;
    GoBack: TSpeedButton;
    LoadButton: TSpeedButton;
    WPToolButton2: TWPToolButton;
    GoNext: TSpeedButton;
    WPComboBox1: TWPComboBox;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure LoadButtonClick(Sender: TObject);
    procedure GoBackClick(Sender: TObject);
    procedure WPRichText1HTMLBitmapRequest(Sender: TObject;
      const SRC: String; var Bitmap: TGraphic);
    procedure GoNextClick(Sender: TObject);
    procedure WPRichText1HyperLinkEvent(Sender: TObject; text,
      stamp: String; LineNumber: Longint);
  private
    { Private-Deklarationen }
    History : TStringList;
    BackHistory : TStringList;
    path    : string;
    FWarning : Boolean;
    procedure HistoryUpdate;
  public
    { Public-Deklarationen }
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}

procedure TForm1.FormCreate(Sender: TObject);
begin
  History := TStringList.Create;
  BackHistory := TStringList.Create;
end;

procedure TForm1.FormDestroy(Sender: TObject);
begin
  History.Free;
  BackHistory.Free;
end;

procedure TForm1.LoadButtonClick(Sender: TObject);
var
   s : string;
begin
   if OpenDialog1.Execute then
   begin
      s := OpenDialog1.FileName;
      path := ExtractFilePath(s);
      WPRichText1.HTMLFilePath := path;
      WPRichText1.Clear;
      WPRichText1.LoadFromFile(s);
      if WPRichText1.LastError=ecOK then
        History.Add(s);
      HistoryUpdate;
   end;
end;

procedure TForm1.GoBackClick(Sender: TObject);
var
  s : string;
begin
  if History.Count>1 then
  begin
     WPRichText1.Clear;
     s := History.Strings[History.Count-1];
     path := ExtractFilePath(s);
     WPRichText1.HTMLFilePath := path;
     WPRichText1.LoadFromFile(s);
     History.Delete(History.Count-1);
     BackHistory.Add(s);
  end else                  
  begin WPRichText1.Clear;
        if History.Count>0 then
           BackHistory.Add(History.Strings[0]);
        History.Clear;
  end;
  HistoryUpdate;
end;

procedure TForm1.GoNextClick(Sender: TObject);
var
  s : string;
begin
  if BackHistory.Count>0 then
  begin
     WPRichText1.Clear;
     s := BackHistory.Strings[BackHistory.Count-1];
     path := ExtractFilePath(s);
     WPRichText1.HTMLFilePath := path;
     WPRichText1.LoadFromFile(s);
     BackHistory.Delete(BackHistory.Count-1);
     History.Add(s);
     HistoryUpdate;
  end;
end;

procedure TForm1.HistoryUpdate;
begin
    GoBack.Enabled := History.Count>0;
    GoNext.Enabled := BackHistory.Count>0;
end;


procedure TForm1.WPRichText1HTMLBitmapRequest(Sender: TObject;
  const SRC: String; var Bitmap: TGraphic);
var
  s : string;
begin
  s := UpperCase( src );
  if pos('BMP',s)>0 then
  begin
     s := path + ExtractFileName(s);
     bitmap := TBitmap.Create;
     bitmap.LoadFromFile(s);
  end else if not FWarning then
  begin
     ShowMessage('Only BMP Bitmapfiles are supported.' + #13 +
                 'Please use a grahics-libary to load other formats');
     FWarning := TRUE;
  end;
end;


procedure TForm1.WPRichText1HyperLinkEvent(Sender: TObject; text,
  stamp: String; LineNumber: Longint);
begin
   if not FileExists(stamp) then
   begin
      stamp := path + ExtractFileName(stamp);
   end else
   begin
      path := ExtractFilePath(stamp);
      WPRichText1.HTMLFilePath := path;
   end;

   if FileExists(stamp) then
   begin
      WPRichText1.Clear;
      WPRichText1.LoadFromFile(stamp);
      if WPRichText1.LastError=ecOK then History.Add(stamp);
      HistoryUpdate;
   end else MessageBeep(0);
end;

end.
